hf-mem-0.0.1-dev1 is not a library.
hf-mem
CLI to estimate the required memory to run inference with Hugging Face models
License
This project is licensed under either of the following licenses, at your option:
Unless you explicitly state otherwise, any contribution intentionally submitted for inclusion in this project by you, as defined in the Apache-2.0 license, shall be dual licensed as above, without any additional terms or conditions.